# modeproc

In `modeproc.py`, processes for each input mode of the structuring process are defined.

## invoice_mode_process

::: src.rdetoolkit.modeproc.invoice_mode_process

## excel_invoice_mode_process

::: src.rdetoolkit.modeproc.excel_invoice_mode_process

## rdeformat_mode_process

::: src.rdetoolkit.modeproc.rdeformat_mode_process

## copy_input_to_rawfile_for_rdeformat

::: src.rdetoolkit.modeproc.copy_input_to_rawfile_for_rdeformat

## multifile_mode_process

::: src.rdetoolkit.modeproc.multifile_mode_process

## copy_input_to_rawfile

::: src.rdetoolkit.modeproc.copy_input_to_rawfile

## selected_input_checker

::: src.rdetoolkit.modeproc.selected_input_checker
